@@ -1,3 +1,5 @@
+from datetime import datetime
+
 from . import errors
 import pytest
 
@@ -9,19 +11,22 @@ class TestGeneral:
     def test_stores_credentials(self, connector, good_credentials):
         assert connector.credentials == good_credentials
 
+    def test_env_has_object_id(self, good_credentials):
+        assert "object_id" in good_credentials
+
 
 class TestAuth:
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.authenticate
-    def test_pass_returns_bool(self, good_authentication):
+    def test_returns_bool(self, good_authentication):
         results = good_authentication
         assert type(results) is bool
 
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.authenticate
-    def test_pass_returns_true(self, good_authentication):
+    def test_returns_true(self, good_authentication):
         results = good_authentication
         assert results
 
@@ -38,26 +43,26 @@ class TestGetObjects:
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.get_objects
-    def test_pass_returns(self, get_good_objects):
+    def test_returns(self, get_good_objects):
         # Since we are using a test account, we should have made some objects when we made the account
         assert get_good_objects
 
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.get_objects
-    def test_pass_returns_list(self, get_good_objects):
+    def test_returns_list(self, get_good_objects):
         assert type(get_good_objects) is list
 
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.get_objects
-    def test_pass_returns_nonempty_list(self, get_good_objects):
+    def test_returns_nonempty_list(self, get_good_objects):
         assert len(get_good_objects) > 0
 
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.get_objects
-    def test_pass_returns_dicts_in_list(self, get_good_objects):
+    def test_returns_dicts_in_list(self, get_good_objects):
         objects = get_good_objects
         for obj in objects:
             assert type(obj) is dict
@@ -65,7 +70,7 @@ class TestGetObjects:
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.get_objects
-    def test_pass_returns_nonempty_dicts_in_list(self, get_good_objects):
+    def test_returns_nonempty_dicts_in_list(self, get_good_objects):
         objects = get_good_objects
         for obj in objects:
             assert len(obj) > 0
@@ -73,7 +78,7 @@ class TestGetObjects:
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.get_objects
-    def test_pass_returns_object_id_in_dict(self, get_good_objects):
+    def test_returns_object_id_in_dict(self, get_good_objects):
         objects = get_good_objects
         for obj in objects:
             assert "object_id" in obj
@@ -81,7 +86,7 @@ class TestGetObjects:
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.get_objects
-    def test_pass_returns_object_name_in_dict(self, get_good_objects):
+    def test_returns_object_name_in_dict(self, get_good_objects):
         objects = get_good_objects
         for obj in objects:
             assert "object_name" in obj
@@ -89,7 +94,7 @@ class TestGetObjects:
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.get_objects
-    def test_pass_returns_object_label_in_dict(self, get_good_objects):
+    def test_returns_object_label_in_dict(self, get_good_objects):
         objects = get_good_objects
         for obj in objects:
             assert "object_label" in obj
@@ -97,7 +102,7 @@ class TestGetObjects:
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.get_objects
-    def test_pass_returns_object_group_in_dict(self, get_good_objects):
+    def test_returns_object_group_in_dict(self, get_good_objects):
         objects = get_good_objects
         for obj in objects:
             assert "object_group" in obj
@@ -113,75 +118,68 @@ class TestGetFields:
 
     @pytest.mark.source
     @pytest.mark.get_fields
-    def test_pass_returns_list(self, get_good_fields):
+    def test_returns_list(self, get_good_fields):
         results = get_good_fields
         assert type(results) is list
 
     @pytest.mark.source
     @pytest.mark.get_fields
-    def test_pass_returns_nonempty_list(self, get_good_fields):
+    def test_returns_nonempty_list(self, get_good_fields):
         results = get_good_fields
         assert len(results) > 0
 
     @pytest.mark.source
     @pytest.mark.get_fields
-    def test_pass_returns_dicts_in_list(self, get_good_fields):
+    def test_returns_dicts_in_list(self, get_good_fields):
         fields = get_good_fields
         for field in fields:
             assert type(field) is dict
 
     @pytest.mark.source
     @pytest.mark.get_fields
-    def test_pass_returns_nonempty_dicts_in_list(self, get_good_fields):
+    def test_returns_nonempty_dicts_in_list(self, get_good_fields):
         fields = get_good_fields
         for field in fields:
             assert len(field) > 0
 
     @pytest.mark.source
     @pytest.mark.get_fields
-    def test_pass_returns_field_id_in_dict(self, get_good_fields):
+    def test_returns_field_id_in_dict(self, get_good_fields):
         fields = get_good_fields
         for field in fields:
             assert "field_id" in field
 
     @pytest.mark.source
     @pytest.mark.get_fields
-    def test_pass_returns_field_name_in_dict(self, get_good_fields):
+    def test_returns_field_name_in_dict(self, get_good_fields):
         fields = get_good_fields
         for field in fields:
             assert "field_name" in field
 
     @pytest.mark.source
     @pytest.mark.get_fields
-    def test_pass_returns_field_label_in_dict(self, get_good_fields):
+    def test_returns_field_label_in_dict(self, get_good_fields):
         fields = get_good_fields
         for field in fields:
             assert "field_label" in field
 
     @pytest.mark.source
     @pytest.mark.get_fields
-    def test_pass_returns_field_group_in_dict(self, get_good_fields):
-        fields = get_good_fields
-        for field in fields:
-            assert "field_group" in field
-
-    @pytest.mark.source
-    @pytest.mark.get_fields
-    def test_pass_returns_data_type_in_dict(self, get_good_fields):
+    def test_returns_data_type_in_dict(self, get_good_fields):
         fields = get_good_fields
         for field in fields:
             assert "data_type" in field
 
     @pytest.mark.source
     @pytest.mark.get_fields
-    def test_pass_returns_size_in_dict(self, get_good_fields):
+    def test_returns_size_in_dict(self, get_good_fields):
         fields = get_good_fields
         for field in fields:
             assert "size" in field
 
     @pytest.mark.source
     @pytest.mark.get_fields
-    def test_fail_bad_object_id_throws_error(self, bad_object_id, connector):
+    def test_bad_object_id_throws_error(self, bad_object_id, connector):
         with pytest.raises(errors.BadObjectIDError):
             connector.authenticate()
             connector.get_fields(bad_object_id)
@@ -190,52 +188,52 @@ class TestGetFields:
 class TestGetData:
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_pass_returns(self, get_good_data_small):
+    def test_returns(self, get_good_data_small):
         # Since we are using a test account, we should have made some data for the selected object_id
         data = get_good_data_small
         assert data
 
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_pass_returns_dict(self, get_good_data_small):
+    def test_returns_dict(self, get_good_data_small):
         data = get_good_data_small
         assert type(data) is dict
 
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_pass_returns_data_in_dict(self, get_good_data_small):
+    def test_returns_data_in_dict(self, get_good_data_small):
         data = get_good_data_small
         assert "data" in data
 
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_pass_returns_data_as_list(self, get_good_data_small):
+    def test_returns_data_as_list(self, get_good_data_small):
         data = get_good_data_small
         assert type(data["data"]) is list
 
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_pass_returns_nonempty_list(self, get_good_data_small):
+    def test_returns_nonempty_list(self, get_good_data_small):
         data = get_good_data_small
         assert len(data["data"]) > 0
 
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_pass_returns_dicts_in_list(self, get_good_data_small):
+    def test_returns_dicts_in_list(self, get_good_data_small):
         data = get_good_data_small
         for obj in data["data"]:
             assert type(obj) is dict
 
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_pass_filters_by_field_id(self, good_object_id, get_three_good_field_ids, connector):
+    def test_filters_by_field_id(self, good_object_id, get_three_good_field_ids, connector):
         connector.authenticate()
         data = connector.get_data(good_object_id, get_three_good_field_ids)
         assert len(data["data"][0].keys()) == len(get_three_good_field_ids)
 
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_fail_bad_field_id_throws_error(self, good_object_id, bad_field_ids, connector):
+    def test_bad_field_id_throws_error(self, good_object_id, bad_field_ids, connector):
         with pytest.raises(errors.BadFieldIDError):
             connector.authenticate()
             connector.get_data(good_object_id, bad_field_ids)
@@ -248,46 +246,90 @@ class TestGetData:
 
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_pass_returns_nonempty_dicts_in_list(self, get_good_data_small):
+    def test_returns_nonempty_dicts_in_list(self, get_good_data_small):
         data = get_good_data_small
         for obj in data["data"]:
             assert len(obj) > 0
 
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_pass_returns_next_page_flag(self, get_good_data_small):
+    def test_returns_next_page_flag(self, get_good_data_small):
         data = get_good_data_small
         assert "next_page" in data
 
+    @pytest.mark.source
+    @pytest.mark.get_data
+    def test_filters_by_custom_date_returns(self, good_object_id, get_three_good_field_ids, connector, filtered_column_nm):
+        connector.authenticate()
+        data = connector.get_data(good_object_id,
+                                  get_three_good_field_ids,
+                                  filters={
+                                      'filtered_column_nm': filtered_column_nm,
+                                      'start_selection_nm': "Custom Date",
+                                      'end_selection_nm': "Custom Date",
+                                      'start_value_txt': "1941-03-26",
+                                      'end_value_txt': "2000-01-01",
+                                      'timezone_offset_nbr': "1"
+                                  })
+        assert data
+
+    @pytest.mark.source
+    @pytest.mark.get_data
+    def test_filters_by_custom_date_works(self,
+                                          good_object_id,
+                                          get_three_good_field_ids,
+                                          connector,
+                                          filtered_column_nm,
+                                          filtered_column_date_format,
+                                          custom_date_start_val,
+                                          custom_date_end_val):
+        connector.authenticate()
+        data = connector.get_data(good_object_id,
+                                  get_three_good_field_ids,
+                                  filters={
+                                      'filtered_column_nm': filtered_column_nm,
+                                      'start_selection_nm': "Custom Date",
+                                      'end_selection_nm': "Custom Date",
+                                      'start_value_txt': custom_date_start_val,
+                                      'end_value_txt': custom_date_end_val,
+                                      'timezone_offset_nbr': "1"
+                                  },
+                                  n_rows=5)
+        start = datetime.strptime(custom_date_start_val, "%Y-%m-%d")
+        end = datetime.strptime(custom_date_end_val, "%Y-%m-%d")
+        for row in data:
+            assert start < datetime.strptime(data[row][filtered_column_nm], filtered_column_date_format)
+            assert datetime.strptime(data[row][filtered_column_nm], filtered_column_date_format) < end
+
 
 class TestGetMetaData:
     @pytest.mark.destination
     @pytest.mark.get_meta_data
-    def test_pass_returns_column_type_flg(self, get_good_meta_data):
+    def test_returns_column_type_flg(self, get_good_meta_data):
         data = get_good_meta_data
         assert "column_type_flg" in data
 
     @pytest.mark.destination
     @pytest.mark.get_meta_data
-    def test_pass_returns_size_flg(self, get_good_meta_data):
+    def test_returns_size_flg(self, get_good_meta_data):
         data = get_good_meta_data
         assert "size_flg" in data
 
     @pytest.mark.destination
     @pytest.mark.get_meta_data
-    def test_pass_returns_new_object_regex(self, get_good_meta_data):
+    def test_returns_new_object_regex(self, get_good_meta_data):
         data = get_good_meta_data
         assert "new_object_regex" in data
 
     @pytest.mark.destination
     @pytest.mark.get_meta_data
-    def test_pass_returns_size_regex(self, get_good_meta_data):
+    def test_returns_size_regex(self, get_good_meta_data):
         data = get_good_meta_data
         assert "size_regex" in data
 
     @pytest.mark.destination
     @pytest.mark.get_meta_data
-    def test_pass_returns_data_types(self, get_good_meta_data):
+    def test_returns_data_types(self, get_good_meta_data):
         data = get_good_meta_data
         assert "data_types" in data
 
